/* ================================================================================================================================
  Christian Thomas July 2019 adapted from Andrew Pericak, July 2016
  
  This script will create GEE Export tasks for you to download R-G-B-NIR imagery from Landsat and NAIP, to match the years used 
  in the MTM analysis scripts. This imagery can then be used for running the accuracy assessment. Note that Landsat covers all 
  years, but that NAIP only starts in 2006, and it only selectively covers some states each year. This script will export imagery 
  only falling directly underneath given sample areas (plots), plus a 1 km buffer around those sample plots.
-----------------------------------------------------------------------------------------------------------------------------------
	The methodology of the MTM data produced for PLOS One relied on the now deprecated Pre-Collection Landsat data. The USGS 
	Switched to the Collection format around May 2017. This change has prompted a shift to use USGS Landsat Collection 1 Tier 1 and 
	Real-Time Raw Scenes, and is reflected here. Read about the original study here: 
	https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0197758
================================================================================================================================ */

// CHANGE THE YEAR for whatever year you need imagery
var year = 1984;  // 1984-2019

var sampleAreas = ee.FeatureCollection('users/skytruth-data/MTR/AccuracyAreas/used_Accuracy_Areas');
var sampleAreaBuffer = sampleAreas.geometry().buffer(1000); // Sample areas buffered 1 km to get surroundings
var exportbounds = sampleAreaBuffer.bounds();

/* ---------------------------------------------- LANDSAT EXPORTING ------------------------------------------------------------ */
// These if-else if statements will select the proper imagery based on whatever year you're looking at and run the TOA conversion, 
// and then a median filter (per the GEE tutorials; they look nice.)

if (year > 1983 && year <= 2011){
  var LSimagery = ee.Image(ee.ImageCollection("LANDSAT/LT05/C01/T1_TOA")  // Landsat 5: 1984 - 2011
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B1","B2","B3","B4");
    })
    //.median());
    .reduce(ee.Reducer.percentile([15])));
}
else if (year == 2012){
  var LSimagery = ee.Image(ee.ImageCollection("LANDSAT/LE07/C01/T1_TOA")  // Landsat 7: 2012
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B1","B2","B3","B4");
    })
    //.median());
    .reduce(ee.Reducer.percentile([15])));
}
else if (year >= 2013){
  var LSimagery = ee.Image(ee.ImageCollection("LANDSAT/LC08/C01/T1_TOA")  // Landsat 8: 2013 - 
    .filterDate(year+"-01-01", year+"-12-31")
    .filterMetadata("CLOUD_COVER", "less_than", 10)
    .map(function(image){
      var clipped = image.clip(sampleAreaBuffer);
      return clipped.select("B2","B3","B4","B5");
    })
    //.median());
    .reduce(ee.Reducer.percentile([15])));
}

// This exports the Landsat imagery
Export.image.toDrive({
  image: LSimagery,
  description: "REVISED_Landsat_"+year,
  region: exportbounds,
  scale: 30,
  crs: "EPSG:5072",
  maxPixels: 1e10,
  folder: "MTM_LANDSAT_IMAGES"  // Whatever GDrive folder you're using; note you don't need a "file path"
});

Map.addLayer(LSimagery,{bands:['B3_p15','B2_p15','B1_p15'],min:0.03,max:0.25},'TOA '+year);

// --------------------------------------------- NAIP EXPORTNG -------------------------------------------------------------------- 
/*
// 2016, 2014, 2012 (partial), 2011 (partial), 2010 (partial), 2009 (partial), 2008 (partial), 2007 (partial), 2005 (partial), 
var naip_year = 2005;
var naip = ee.ImageCollection("USDA/NAIP/DOQQ").select('R', 'G', 'B').filterDate(naip_year+'-01-01', naip_year+'-12-31').mosaic().clip(sampleAreaBuffer);
Map.addLayer(naip, {min:0,max:255},'NAIP '+naip_year);

Export.image.toDrive({
  image: naip,
  description: "NAIP_"+naip_year,
  region: exportbounds,
  scale: 1,
  crs: "EPSG:4326",
  maxPixels: 1e11,
  folder: "MTM_LANDSAT_IMAGES"
});
*/